@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _PROCESS_OUTPUT_LOG_FILE_READER_H_
-#define _PROCESS_OUTPUT_LOG_FILE_READER_H_
+#ifndef PROCESS_OUTPUT_LOG_FILE_READER_H
+#define PROCESS_OUTPUT_LOG_FILE_READER_H
 
 #define PROCESS_OUTPUT_UPDATER_INTERVAL 10000
 
@@ -39,15 +39,15 @@ class ProcessOutputLogFileReader : public LogFileReader
     Q_OBJECT
 
 public:
-    ProcessOutputLogFileReader(const LogFile &logFile);
+    explicit ProcessOutputLogFileReader(const LogFile &logFile);
 
-    virtual ~ProcessOutputLogFileReader();
+    ~ProcessOutputLogFileReader() override;
 
-    void watchFile(bool enable) Q_DECL_OVERRIDE;
+    void watchFile(bool enable) override;
 
     void setPreviousFilePosition(long previousFilePosition);
 
-private slots:
+private Q_SLOTS:
     void startProcess();
 
     void logFileModified();
@@ -68,4 +68,4 @@ private:
     Q_DECLARE_PRIVATE(ProcessOutputLogFileReader)
 };
 
-#endif // _PROCESS_OUTPUT_LOG_FILE_READER_H_
+#endif // _PROCESS_OUTPUT_LOG_FILE_READER_H
