@@ -61,7 +61,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~MainWindow();
+    ~MainWindow() override;
 
     TabLogViewsWidget *tabs();
 
@@ -70,21 +70,21 @@ protected:
      * This function is called when it is time for the app to save its
      * properties for session management purposes.
      */
-    void saveProperties(KConfigGroup &configuration) Q_DECL_OVERRIDE;
+    void saveProperties(KConfigGroup &configuration) override;
 
     /**
      * This function is called when this app is restored.  The KConfig
      * object points to the session management config file that was saved
      * with @ref saveProperties
      */
-    void readProperties(const KConfigGroup &configuration) Q_DECL_OVERRIDE;
+    void readProperties(const KConfigGroup &configuration) override;
 
     /**
      * Reimplemented to save configuration when closing.
      */
-    void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent *event) override;
 
-public slots:
+public Q_SLOTS:
     void changeStatusBar(const QString &text);
     void changeWindowTitle(const QString &text);
 
@@ -92,7 +92,7 @@ public slots:
 
     void prepareCreatedLogManager(LogManager *logManager);
 
-private slots:
+private Q_SLOTS:
     void fileOpen();
 
     void showConfigurationDialog();
