@@ -30,15 +30,12 @@
 
 #include <QtConcurrent>
 
-JournaldLocalAnalyzer::JournaldLocalAnalyzer(LogMode *logMode, QString filter)
-    : JournaldAnalyzer(logMode)
+JournaldLocalAnalyzer::JournaldLocalAnalyzer(LogMode *mode, QString filter)
+    : JournaldAnalyzer(mode)
 {
-    m_cursor = nullptr;
-    m_forgetWatchers = true;
-
     // Initialize journal access flags and open the journal.
     m_journalFlags = 0;
-    JournaldConfiguration *configuration = logMode->logModeConfiguration<JournaldConfiguration *>();
+    JournaldConfiguration *configuration = mode->logModeConfiguration<JournaldConfiguration *>();
     switch (configuration->entriesType()) {
     case JournaldConfiguration::EntriesAll:
         break;
@@ -51,7 +48,11 @@ JournaldLocalAnalyzer::JournaldLocalAnalyzer(LogMode *logMode, QString filter)
     default:
         break;
     }
-    sd_journal_open(&m_journal, m_journalFlags);
+    int ret = sd_journal_open(&m_journal, m_journalFlags);
+    if (ret < 0) {
+        logWarning() << "Journald analyzer failed to open system journal";
+        return;
+    }
 
     qintptr fd = sd_journal_get_fd(m_journal);
     m_journalNotifier = new QSocketNotifier(fd, QSocketNotifier::Read);
@@ -86,6 +87,8 @@ JournaldLocalAnalyzer::~JournaldLocalAnalyzer()
 
 void JournaldLocalAnalyzer::watchLogFiles(bool enabled)
 {
+    if (!m_journalNotifier)
+        return;
     m_journalNotifier->setEnabled(enabled);
 
     m_workerMutex.lock();
@@ -153,7 +156,7 @@ void JournaldLocalAnalyzer::readJournalFinished(ReadingMode readingMode)
 
     if (parsingPaused) {
         logDebug() << "Parsing is paused, discarding journald entries.";
-    } else if (entries.size() == 0) {
+    } else if (entries.empty()) {
         logDebug() << "Received no entries.";
     } else {
         insertionLocking.lock();
@@ -250,7 +253,7 @@ QList<JournaldLocalAnalyzer::JournalEntry> JournaldLocalAnalyzer::readJournal(co
     }
 
     sd_journal_close(journal);
-    if (entryList.size() > 0)
+    if (!entryList.empty())
         logDebug() << "Read" << entryList.size() << "journal entries.";
     return entryList;
 }
@@ -360,7 +363,7 @@ JournaldLocalAnalyzer::JournalEntry JournaldLocalAnalyzer::readJournalEntry(sd_j
     return entry;
 }
 
-QStringList JournaldLocalAnalyzer::getUniqueFieldValues(const QString id, int flags)
+QStringList JournaldLocalAnalyzer::getUniqueFieldValues(const QString &id, int flags)
 {
     QStringList units;
     sd_journal *journal;
