@@ -46,7 +46,7 @@ TestUtil::~TestUtil()
 
 void TestUtil::registerLogModeFactories() const
 {
-    logDebug() << "Registering existing log mode factories" << endl;
+    logDebug() << "Registering existing log mode factories";
     Globals::instance().registerLogModeFactory(new SystemLogModeFactory());
     Globals::instance().registerLogModeFactory(new KernelLogModeFactory());
 }
@@ -79,7 +79,7 @@ void TestUtil::destroyReader(Analyzer *analyzer) const
 QList<LogFile> TestUtil::createLogFiles(const QString &resourceFileName) const
 {
     QTemporaryFile *tempFile = QTemporaryFile::createNativeFile(resourceFileName);
-    logDebug() << "Using log file name " << tempFile << endl;
+    logDebug() << "Using log file name " << tempFile;
     tempFile->setPermissions(QFile::WriteUser | QFile::ReadUser | QFile::ReadOwner | QFile::WriteOwner);
 
     LogLevel *informationLogLevel = Globals::instance().informationLogLevel();
@@ -111,11 +111,11 @@ void TestUtil::addLogLines(const QString &fileName, const QStringList &addedLine
 
     QFile data(fileName);
     if (data.open(QFile::Append | QIODevice::Text)) {
-        logDebug() << "Opening " << fileName << " for writing " << addedLines.count() << " line(s)." << endl;
+        logDebug() << "Opening " << fileName << " for writing " << addedLines.count() << " line(s).";
 
         QTextStream out(&data);
         foreach (const QString &line, addedLines) {
-            out << line << endl;
+            out << line << '\n';
         }
 
         out.flush();
